@@ -1,6 +1,6 @@
 from .version import __version__
 import click
-import importlib
+import importlib, importlib.util
 import logging
 from os.path import dirname, basename, join
 from glob import glob
@@ -19,7 +19,13 @@ from .utils import logger
     type=str,
     default=logger.LOG_LEVEL_DEFAULT_STR,
 )
-def main(log_level):
+@click.option(
+    '--plugins',
+    'plugin_dir',
+    help='Directory to load plugins from',
+    type = click.Path(exists=True, file_okay=False)
+)
+def main(log_level, plugin_dir):
     level = logger.get_log_level(log_level)
     logging.basicConfig(level=level)
 
@@ -30,6 +36,12 @@ def main(log_level):
             continue
         importlib.import_module('launchable.test_runners.%s' % f)
 
+    # load all plugins
+    if plugin_dir:
+        for f in glob(join(plugin_dir, '*.py')):
+            spec = importlib.util.spec_from_file_location("launchable.plugins.{}".format(basename(f)[:-3]), f)
+            plugin = importlib.util.module_from_spec(spec)
+            spec.loader.exec_module(plugin)
 
 main.add_command(record)
 main.add_command(subset)
