@@ -8,16 +8,14 @@ import xml.etree.ElementTree as ET
 from typing import Callable, Dict, Generator, Iterator, List, Optional
 from more_itertools import ichunked
 from .case_event import CaseEvent
-from ...utils.gzipgen import compress
 from ...utils.http_client import LaunchableClient
-from ...utils.token import parse_token
 from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.session import parse_session
 from ...testpath import TestPathComponent
 from ..helper import find_or_create_session
 from http import HTTPStatus
 from ...utils.click import KeyValueType
-from ...utils.logger import Logger, AUDIT_LOG_FORMAT
+from ...utils.logger import Logger
 import datetime
 from dateutil.parser import parse
 
@@ -63,12 +61,11 @@ from dateutil.parser import parse
     multiple=True,
 )
 @click.pass_context
-def tests(context, base_path: str, session: Optional[str], build_name: Optional[str], debug: bool, post_chunk: int, flavor):
+def tests(context, base_path: str, session: Optional[str], build_name: Optional[str], debug: bool, post_chunk: int,
+          flavor):
     session_id = find_or_create_session(context, session, build_name, flavor)
 
-    token, org, workspace = parse_token()
-    record_start_at = get_record_start_at(
-        token, org, workspace, build_name, session)
+    record_start_at = get_record_start_at(build_name, session)
 
     logger = Logger()
 
@@ -76,14 +73,14 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
     # PR merge hell. This should be moved to a top-level class
 
     class RecordTests:
-        CaseEventType = Dict[str,str]
+        CaseEventType = Dict[str, str]
         # The most generic form of parsing, where a path to a test report
         # is turned into a generator by using CaseEvent.create()
-        ParseFunc = Callable[[str], Generator[CaseEventType,None,None]]
+        ParseFunc = Callable[[str], Generator[CaseEventType, None, None]]
 
         # A common mechanism to build ParseFunc by building JUnit XML report in-memory (or build it the usual way
         # and patch it to fix things up). This is handy as some libraries produce invalid / broken JUnit reports
-        JUnitXmlParseFunc = Callable[[str],  ET.Element]
+        JUnitXmlParseFunc = Callable[[str], ET.Element]
 
         @property
         def path_builder(self) -> CaseEvent.TestPathBuilder:
@@ -113,7 +110,8 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
 
             If f=None, the default parse code from JUnitParser module is used.
             """
-            def parse(report: str) -> Generator[RecordTests.CaseEventType,None,None]:
+
+            def parse(report: str) -> Generator[RecordTests.CaseEventType, None, None]:
                 # To understand JUnit XML format, https://llg.cubic.org/docs/junit/ is helpful
                 # TODO: robustness: what's the best way to deal with broken XML file, if any?
                 xml = JUnitXml.fromfile(report, f)
@@ -128,9 +126,10 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
                 for suite in testsuites:
                     for case in suite:
                         yield CaseEvent.from_case_and_suite(self.path_builder, case, suite, report)
-            self.parse_func = parse
-        junitxml_parse_func = property(None, set_junitxml_parse_func)
 
+            self.parse_func = parse
+
+        junitxml_parse_func = property(None, set_junitxml_parse_func)
 
         @property
         def check_timestamp(self):
@@ -142,6 +141,7 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
 
         def __init__(self):
             self.reports = []
+            self.skipped_reports = []
             self.path_builder = CaseEvent.default_path_builder(base_path)
             self.junitxml_parse_func = None
             self.check_timestamp = True
@@ -158,8 +158,10 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
 
             if self.check_timestamp and ctime.timestamp() < record_start_at.timestamp():
                 format = "%Y-%m-%d %H:%M:%S"
-                logger.debug("skip: {} is old to report. start_record_at: {} file_created_at:{}".format(
+                logger.warning("skip: {} is too old to report. start_record_at: {} file_created_at: {}".format(
                     junit_report_file, record_start_at.strftime(format), ctime.strftime(format)))
+                self.skipped_reports.append(junit_report_file)
+
                 return
 
             self.reports.append(junit_report_file)
@@ -174,12 +176,10 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
                 self.report(t)
 
         def run(self):
-            count = 0   # count number of test cases sent
+            count = 0  # count number of test cases sent
+            client = LaunchableClient(test_runner=context.invoked_subcommand)
 
-            client = LaunchableClient(
-                token, test_runner=context.invoked_subcommand)
-
-            def testcases(reports: List[str]) -> Generator[RecordTests.CaseEventType,None,None]:
+            def testcases(reports: List[str]) -> Generator[RecordTests.CaseEventType, None, None]:
                 exceptions = []
                 for report in reports:
                     try:
@@ -193,76 +193,57 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
                     # defer XML parsing exceptions so that we can send what we can send before we bail out
                     raise Exception(exceptions)
 
-            def splitter(iterable: Generator, size: int) -> Iterator[Iterator]:
-                return ichunked(iterable, size)
-
             # generator that creates the payload incrementally
-            def payload(cases: Generator[TestCase, None, None]) -> Generator[str, None, None]:
+            def payload(cases: Generator[TestCase, None, None]) -> (Dict[str, List], List[Exception]):
                 nonlocal count
-                yield '{"events": ['
-                first = True        # used to control ',' in printing
-                for case in cases:
-                    if not first:
-                        yield ','
-                    first = False
-                    count += 1
-                    yield case
-                yield ']}'
+                cs = []
+                exs = []
 
-            def printer(f: Generator) -> Generator:
-                for d in f:
-                    print(d)
-                    yield d
+                while True:
+                    try:
+                        cs.append(next(cases))
+                    except StopIteration:
+                        break
+                    except Exception as ex:
+                        exs.append(ex)
 
-            def send(payload: Generator[TestCase, None, None]) -> None:
-                # str -> bytes then gzip compress
-                headers = {
-                    "Content-Type": "application/json",
-                    "Content-Encoding": "gzip",
-                }
+                count += len(cs)
+                return {"events": cs}, exs
 
-                def audit_log(f: Generator) -> Generator:
-                    args = []
-                    for d in f:
-                        args.append(d)
-                        yield d
-
-                    logger.audit(AUDIT_LOG_FORMAT.format(
-                        "post", "{}/events".format(session_id), headers, list(args)))
-
-                payload = (s.encode() for s in audit_log(payload))
-                payload = compress(payload)
-
-                res = client.request(
-                    "post", "{}/events".format(session_id), data=payload, headers=headers)
+            def send(payload: Dict[str, List]) -> None:
+                res = client.request("post", "{}/events".format(session_id), payload=payload, compress=True)
 
                 if res.status_code == HTTPStatus.NOT_FOUND:
                     if session:
-                        _, _, build, _ = parse_session(session)
+                        build, _ = parse_session(session)
                         click.echo(click.style(
-                            "Session {} was not found. Make sure to run `launchable record session --build {}` before `launchable record tests`".format(session, build), 'yellow'), err=True)
+                            "Session {} was not found. Make sure to run `launchable record session --build {}` before `launchable record tests`".format(
+                                session, build), 'yellow'), err=True)
                     elif build_name:
                         click.echo(click.style(
-                            "Build {} was not found. Make sure to run `launchable record build --name {}` before `launchable record tests`".format(build_name, build_name), 'yellow'), err=True)
+                            "Build {} was not found. Make sure to run `launchable record build --name {}` before `launchable record tests`".format(
+                                build_name, build_name), 'yellow'), err=True)
 
                 res.raise_for_status()
 
             try:
-                tc = (json.dumps(d) for d in testcases(self.reports))
+                tc = testcases(self.reports)
                 if debug:
-                    tc = printer(tc)
-                splitted_cases = splitter(tc, post_chunk)
-                for chunk in splitted_cases:
-                    send(payload(chunk))
+                    logger.debug(tc)
 
-                headers = {
-                    "Content-Type": "application/json",
-                    "Content-Encoding": "gzip",
-                }
-                res = client.request(
-                    "patch", "{}/close".format(session_id), headers=headers)
+                exceptions = []
+                for chunk in ichunked(tc, post_chunk):
+                    p, es = payload(chunk)
+
+                    send(p)
+                    exceptions.extend(es)
+
+                res = client.request("patch", "{}/close".format(session_id))
                 res.raise_for_status()
 
+                if len(exceptions) > 0:
+                    raise Exception(exceptions)
+
             except Exception as e:
                 if os.getenv(REPORT_ERROR_KEY):
                     raise e
@@ -272,39 +253,55 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
 
             click.echo("Recorded {} tests".format(count))
             if count == 0:
-                click.echo(click.style(
-                    "Looks like tests didn't run? If not, make sure the right files/directories are passed", 'yellow'))
+                if len(self.skipped_reports) != 0:
+                    click.echo(click.style(
+                        "{} test reports were skipped because they were created before `launchable record build`.\nMake sure to run test after `launchable record build`.".format(len(self.skip_reports)), 'yellow'))
+                else:
+                    click.echo(click.style(
+                        "Looks like tests didn't run? If not, make sure the right files/directories are passed", 'yellow'))
 
     context.obj = RecordTests()
 
 
-def get_record_start_at(token: str, org: str, workspace: str, build_name: Optional[str], session: Optional[str]):
+# if we fail to determine the timestamp of the build, we err on the side of collecting more test reports
+# than no test reports, so we use the 'epoch' timestamp
+INVALID_TIMESTAMP = datetime.datetime.fromtimestamp(0)
+
+def get_record_start_at(build_name: Optional[str], session: Optional[str]):
+    """
+    Determine the baseline timestamp to be used for up-to-date checks of report files.
+    Only files newer than this timestamp will be collected.
+
+    Based on the thinking that if a build doesn't exist tests couldn't have possibly run, we attempt
+    to use the timestamp of a build, with appropriate fallback.
+    """
     if session is None and build_name is None:
         raise click.UsageError(
             'Either --build or --session has to be specified')
 
     if session:
-        _, _, build_name, _ = parse_session(session)
+        build_name, _ = parse_session(session)
 
-    client = LaunchableClient(token)
-    headers = {
-        "Content-Type": "application/json",
-    }
-    path = "/intake/organizations/{}/workspaces/{}/builds/{}".format(
-        org, workspace, build_name)
+    client = LaunchableClient()
+    sub_path = "builds/{}".format(build_name)
 
-    Logger().audit(AUDIT_LOG_FORMAT.format(
-        "get", path, headers, None))
+    res = client.request("get", sub_path)
+    if res.status_code != 200:
+        if res.status_code == 404:
+            msg = "Build {} was not found. Make sure to run `launchable record build --name {}` before `launchable record tests`".format(
+                build_name, build_name)
+        else:
+            msg = "Unable to determine the timestamp of the build {}. HTTP response code was {}".format(build_name,
+                                                                                                        res.status_code)
+        click.echo(click.style(msg, 'yellow'), err=True)
 
-    res = client.request("get", path, headers=headers)
-    if res.status_code == 404:
-        click.echo(click.style(
-            "Build {} was not found. Make sure to run `launchable record build --name {}` before `launchable record tests`".format(build_name, build_name), 'yellow'), err=True)
-    elif res.status_code != 200:
         # to avoid stop report command
-        return datetime.datetime.now()
+        return INVALID_TIMESTAMP
 
-    return parse_launchable_timeformat(res.json()["createdAt"])
+    created_at = res.json()["createdAt"]
+    Logger().debug("Build {} timestamp = {}".format(build_name, created_at))
+    t = parse_launchable_timeformat(created_at)
+    return t
 
 
 def parse_launchable_timeformat(t: str) -> datetime.datetime:
@@ -312,6 +309,5 @@ def parse_launchable_timeformat(t: str) -> datetime.datetime:
     try:
         return parse(t)
     except Exception as e:
-        Logger().error(
-            "parse time error {}. time: {}".format(str(e), t))
-        return datetime.datetime.now()
+        Logger().error("parse time error {}. time: {}".format(str(e), t))
+        return INVALID_TIMESTAMP
