@@ -22,7 +22,7 @@ def record_tests(client, reports):
                         suite.attrib.update({"filepath": filepath})
         return tree
 
-    client._junitxml_parse_func = parse_func
+    client.junitxml_parse_func = parse_func
     client.run()
 
 
